@@ -19,7 +19,6 @@
 
 import random, ast, re, errno, os
 import threading, traceback, sys, time, json, Queue
-import socks
 import socket
 import ssl
 
@@ -27,41 +26,14 @@ import requests
 ca_path = requests.certs.where()
 
 from version import ELECTRUM_VERSION, PROTOCOL_VERSION
-from util import print_error, print_msg
+import util
 from simple_config import SimpleConfig
 
 import x509
-
-DEFAULT_TIMEOUT = 5
-proxy_modes = ['socks4', 'socks5', 'http']
-
-
 import util
 
-def serialize_proxy(p):
-    if type(p) != dict:
-        return None
-    return ':'.join([p.get('mode'),p.get('host'), p.get('port')])
+DEFAULT_TIMEOUT = 5
 
-def deserialize_proxy(s):
-    if type(s) != str:
-        return None
-    if s.lower() == 'none':
-        return None
-    proxy = { "mode":"socks5", "host":"localhost" }
-    args = s.split(':')
-    n = 0
-    if proxy_modes.count(args[n]) == 1:
-        proxy["mode"] = args[n]
-        n += 1
-    if len(args) > n:
-        proxy["host"] = args[n]
-        n += 1
-    if len(args) > n:
-        proxy["port"] = args[n]
-    else:
-        proxy["port"] = "8080" if proxy["mode"] == "http" else "1080"
-    return proxy
 
 
 def Interface(server, config = None):
@@ -69,8 +41,6 @@ def Interface(server, config = None):
     port = int(port)
     if protocol in 'st':
         return TcpInterface(server, config)
-    elif protocol in 'hg':
-        return HttpInterface(server, config)
     else:
         raise Exception('Unknown protocol: %s'%protocol)
 
@@ -92,20 +62,13 @@ class TcpInterface(threading.Thread):
         self.host, self.port, self.protocol = self.server.split(':')
         self.port = int(self.port)
         self.use_ssl = (self.protocol == 's')
-        self.proxy = deserialize_proxy(self.config.get('proxy'))
-        if self.proxy:
-            self.proxy_mode = proxy_modes.index(self.proxy["mode"]) + 1
-            socks.setdefaultproxy(self.proxy_mode, self.proxy["host"], int(self.proxy["port"]))
-            socket.socket = socks.socksocket
-            # prevent dns leaks, see http://stackoverflow.com/questions/13184205/dns-over-proxy
-            def getaddrinfo(*args):
-                return [(socket.AF_INET, socket.SOCK_STREAM, 6, '', (args[0], args[1]))]
-            socket.getaddrinfo = getaddrinfo
 
+    def print_error(self, *msg):
+        util.print_error("[%s]"%self.host, *msg)
 
     def process_response(self, response):
         if self.debug:
-            print_error("<--", response)
+            self.print_error("<--", response)
 
         msg_id = response.get('id')
         error = response.get('error')
@@ -174,7 +137,7 @@ class TcpInterface(threading.Thread):
         try:
             l = socket.getaddrinfo(self.host, self.port, socket.AF_UNSPEC, socket.SOCK_STREAM)
         except socket.gaierror:
-            print_error("error: cannot resolve", self.host)
+            self.print_error("cannot resolve hostname")
             return
         for res in l:
             try:
@@ -184,7 +147,7 @@ class TcpInterface(threading.Thread):
             except BaseException as e:
                 continue
         else:
-            print_error("failed to connect", self.host, self.port, str(e))
+            self.print_error("failed to connect", str(e))
 
 
     def get_socket(self):
@@ -201,7 +164,7 @@ class TcpInterface(threading.Thread):
                 except ssl.SSLError, e:
                     s = None
                 if s and self.check_host_name(s.getpeercert(), self.host):
-                    print_error("SSL certificate signed by CA:", self.host)
+                    self.print_error("SSL certificate signed by CA")
                     return s
 
                 # get server certificate.
@@ -210,7 +173,7 @@ class TcpInterface(threading.Thread):
                 try:
                     s = ssl.wrap_socket(s, ssl_version=ssl.PROTOCOL_SSLv23, cert_reqs=ssl.CERT_NONE, ca_certs=None)
                 except ssl.SSLError, e:
-                    print_error("SSL error retrieving SSL certificate:", self.host, e)
+                    self.print_error("SSL error retrieving SSL certificate:", e)
                     return
 
                 dercert = s.getpeercert(True)
@@ -239,7 +202,7 @@ class TcpInterface(threading.Thread):
                                     ca_certs= (temporary_path if is_new else cert_path),
                                     do_handshake_on_connect=True)
             except ssl.SSLError, e:
-                print_error("SSL error:", self.host, e)
+                self.print_error("SSL error:", e)
                 if e.errno != 1:
                     return
                 if is_new:
@@ -256,25 +219,25 @@ class TcpInterface(threading.Thread):
                         x.slow_parse()
                     except:
                         traceback.print_exc(file=sys.stderr)
-                        print_error("wrong certificate", self.host)
+                        self.print_error("wrong certificate")
                         return
                     try:
                         x.check_date()
                     except:
-                        print_error("certificate has expired:", cert_path)
+                        self.print_error("certificate has expired:", cert_path)
                         os.unlink(cert_path)
                         return
-                    print_error("wrong certificate", self.host)
+                    self.print_error("wrong certificate")
                 return
             except BaseException, e:
-                print_error(self.host, e)
+                self.print_error(e)
                 if e.errno == 104:
                     return
                 traceback.print_exc(file=sys.stderr)
                 return
 
             if is_new:
-                print_error("saving certificate for", self.host)
+                self.print_error("saving certificate")
                 os.rename(temporary_path, cert_path)
 
         return s
@@ -289,9 +252,9 @@ class TcpInterface(threading.Thread):
                 r = {'id':self.message_id, 'method':method, 'params':params}
                 self.pipe.send(r)
                 if self.debug:
-                    print_error("-->", r)
+                    self.print_error("-->", r)
             except socket.error, e:
-                print_error("socked error:", self.server, e)
+                self.print_error("socked error:", e)
                 self.is_connected = False
                 return
             self.unanswered_requests[self.message_id] = method, params, _id, queue
@@ -302,6 +265,7 @@ class TcpInterface(threading.Thread):
             self.s.shutdown(socket.SHUT_RDWR)
             self.s.close()
         self.is_connected = False
+        self.print_error("stopped")
 
     def start(self, response_queue):
         self.response_queue = response_queue
@@ -310,38 +274,53 @@ class TcpInterface(threading.Thread):
     def run(self):
         self.s = self.get_socket()
         if self.s:
-            self.s.settimeout(60)
-            self.is_connected = True
-            print_error("connected to", self.host, self.port)
             self.pipe = util.SocketPipe(self.s)
+            self.s.settimeout(2)
+            self.is_connected = True
+            self.print_error("connected")
 
         self.change_status()
         if not self.is_connected:
             return
 
-        t = 0
+        # ping timer
+        ping_time = 0
+        # request timer
+        request_time = False
         while self.is_connected:
             # ping the server with server.version
-            if time.time() - t > 60:
+            if time.time() - ping_time > 60:
                 if self.is_ping:
-                    print_error("ping timeout", self.server)
+                    self.print_error("ping timeout")
                     self.is_connected = False
                     break
                 else:
                     self.send_request({'method':'server.version', 'params':[ELECTRUM_VERSION, PROTOCOL_VERSION]})
                     self.is_ping = True
-                    t = time.time()
+                    ping_time = time.time()
             try:
                 response = self.pipe.get()
             except util.timeout:
+                if self.unanswered_requests:
+                    if request_time is False:
+                        request_time = time.time()
+                        self.print_error("setting timer")
+                    else:
+                        if time.time() - request_time > 10:
+                            self.print_error("request timeout", len(self.unanswered_requests))
+                            self.is_connected = False
+                            break
                 continue
             if response is None:
                 self.is_connected = False
                 break
+            if request_time is not False:
+                self.print_error("stopping timer")
+                request_time = False
             self.process_response(response)
 
         self.change_status()
-        print_error("closing connection:", self.server)
+
 
     def change_status(self):
         # print_error( "change status", self.server, self.is_connected)
@@ -349,123 +328,6 @@ class TcpInterface(threading.Thread):
 
 
 
-class HttpInterface(TcpInterface):
-
-    def run(self):
-        self.start_http()
-        if self.is_connected:
-            self.send_request({'method':'server.version', 'params':[ELECTRUM_VERSION, PROTOCOL_VERSION]})
-            self.change_status()
-            self.run_http()
-        self.change_status()
-
-    def send_request(self, request, queue=None):
-        import urllib2, json, time, cookielib
-        print_error( "send_http", messages )
-
-        if self.proxy:
-            socks.setdefaultproxy(self.proxy_mode, self.proxy["host"], int(self.proxy["port"]) )
-            socks.wrapmodule(urllib2)
-
-        cj = cookielib.CookieJar()
-        opener = urllib2.build_opener(urllib2.HTTPCookieProcessor(cj))
-        urllib2.install_opener(opener)
-
-        t1 = time.time()
-
-        data = []
-        ids = []
-        for m in messages:
-            method, params = m
-            if type(params) != type([]): params = [params]
-            data.append( { 'method':method, 'id':self.message_id, 'params':params } )
-            self.unanswered_requests[self.message_id] = method, params, callback
-            ids.append(self.message_id)
-            self.message_id += 1
-
-        if data:
-            data_json = json.dumps(data)
-        else:
-            # poll with GET
-            data_json = None
-
-
-        headers = {'content-type': 'application/json'}
-        if self.session_id:
-            headers['cookie'] = 'SESSION=%s'%self.session_id
-
-        try:
-            req = urllib2.Request(self.connection_msg, data_json, headers)
-            response_stream = urllib2.urlopen(req, timeout=DEFAULT_TIMEOUT)
-        except Exception:
-            return
-
-        for index, cookie in enumerate(cj):
-            if cookie.name=='SESSION':
-                self.session_id = cookie.value
-
-        response = response_stream.read()
-        self.bytes_received += len(response)
-        if response:
-            response = json.loads( response )
-            if type(response) is not type([]):
-                self.process_response(response)
-            else:
-                for item in response:
-                    self.process_response(item)
-        if response:
-            self.poll_interval = 1
-        else:
-            if self.poll_interval < 15:
-                self.poll_interval += 1
-        #print self.poll_interval, response
-        self.rtime = time.time() - t1
-        self.is_connected = True
-        return ids
-
-    def poll(self):
-        self.send([], None)
-
-    def start_http(self):
-        self.rtime = 0
-        self.bytes_received = 0
-        self.poll_interval = 1
-
-        self.session_id = None
-        self.is_connected = True
-        self.connection_msg = ('https' if self.use_ssl else 'http') + '://%s:%d'%( self.host, self.port )
-        try:
-            self.poll()
-        except Exception:
-            print_error("http init session failed")
-            self.is_connected = False
-            return
-
-        if self.session_id:
-            print_error('http session:',self.session_id)
-            self.is_connected = True
-        else:
-            self.is_connected = False
-
-    def run_http(self):
-        self.is_connected = True
-        while self.is_connected:
-            try:
-                if self.session_id:
-                    self.poll()
-                time.sleep(self.poll_interval)
-            except socket.gaierror:
-                break
-            except socket.error:
-                break
-            except Exception:
-                traceback.print_exc(file=sys.stdout)
-                break
-
-        self.is_connected = False
-
-
-
 
 
 
@@ -486,7 +348,7 @@ def check_cert(host, cert):
 
     m = "host: %s\n"%host
     m += "has_expired: %s\n"% expired
-    print_msg(m)
+    util.print_msg(m)
 
 
 def test_certificates():
